@@ -194,13 +194,4 @@ class ClSetupBootAction(ClSetupSystemAction):
          'warning': _("The builder mode is no longer supported"),
          'condition': lambda Get: Get('os_install_scratch') == 'on'
          },
-        # изменить IO планировщик
-        {'name': 'change_ioscheduler',
-         'message': _("Changing the I/O scheduler"),
-         'method': 'Install.changeScheduler(os_install_kernel_scheduler)',
-         'condition': (lambda dv: dv.Get('os_root_type') != 'livecd' and
-                                  dv.Select('os_disk_parent',
-                                            where='os_disk_mount',
-                                            eq='/', limit=1))
-         },
     ]
