@@ -49,7 +49,7 @@ class VideoVariable(Variable):
     xorg_need = True
     default_video = "default"
     driver_names = OrderedDict([
-        ('default', _("X.Org Server auto detection")),
+        ('default', _("Auto detection")),
         ('radeon', _("AMD Radeon (radeon)")),
         ('amdgpu', _("AMD AMDGPU (amdgpu)")),
         ('fglrx', _("AMD Catalyst (fglrx)")),
